cassy
=======

|PyPI| |Python Version| |License| |Status|

|Stable Release| |Develop Release|

|Read the Docs| |Tests| |Safety| |Pylinting| |Flake8 Linting| |Pre-Commit|

|Codecov| |Codacy| |Codeclimate| |Scrutinizer|

|pre-commit| |Black| |Pylint| |Flake8|

.. |PyPI| image:: https://img.shields.io/pypi/v/cassy.svg
   :target: https://pypi.org/project/cassy/
   :alt: PyPI

.. |Python Version| image:: https://img.shields.io/pypi/pyversions/cassy
   :target: https://pypi.org/project/cassy
   :alt: Python Version

.. |License| image:: https://img.shields.io/pypi/l/cassy
   :target: https://opensource.org/licenses/MIT
   :alt: License

.. |Status| image:: https://img.shields.io/pypi/status/cassy.svg
   :target: https://pypi.org/project/cassy/
   :alt: Status

.. |Stable Release| image:: https://github.com/tZ3ma/cassy/workflows/Stable-PyPI-Release/badge.svg
   :target: https://github.com/tZ3ma/cassy/actions?workflow=Stable-PyPI-Release
   :alt: Stable PyPI Release Workflow Status

.. |Develop Release| image:: https://github.com/tZ3ma/cassy/workflows/Develop-TestPyPI-Release/badge.svg
   :target: https://github.com/tZ3ma/cassy/actions?workflow=Develop-TestPyPI-Release
   :alt: Develop TestPyPI Release Workflow Status

.. |Read the Docs| image:: https://img.shields.io/readthedocs/cassy/latest.svg?label=Read%20the%20Docs
   :target: https://cassy.readthedocs.io/
   :alt: Read the documentation at https://cassy.readthedocs.io/

.. |Tests| image:: https://github.com/tZ3ma/cassy/workflows/Tests-and-Coverage/badge.svg
   :target: https://github.com/tZ3ma/cassy/actions?workflow=Tests-and-Coverage
   :alt: Tests Workflow Status

.. |Safety| image:: https://github.com/tZ3ma/cassy/workflows/Safety/badge.svg
   :target: https://github.com/tZ3ma/cassy/actions?workflow=Safety
   :alt: Safety Workflow Status

.. |Pylinting| image:: https://github.com/tZ3ma/cassy/workflows/Pylinting/badge.svg
   :target: https://github.com/tZ3ma/cassy/actions?workflow=Pylinting
   :alt: Pylint Workflow Status

.. |Flake8 Linting| image:: https://github.com/tZ3ma/cassy/workflows/Flake8-Linting/badge.svg
   :target: https://github.com/tZ3ma/cassy/actions?workflow=Flake8-Linting
   :alt: Flake8-Linting Workflow Status

.. |Pre-Commit| image:: https://github.com/tZ3ma/cassy/workflows/Pre-Commit/badge.svg
   :target: https://github.com/tZ3ma/cassy/actions?workflow=Pre-Commit
   :alt: Pre-Commit Workflow Status

.. |Codecov| image:: https://codecov.io/gh/tZ3ma/cassy/branch/main/graph/badge.svg
   :target: https://codecov.io/gh/tZ3ma/cassy
   :alt: Codecov

.. |Codacy| image:: https://app.codacy.com/project/badge/Grade/b278433bb9224147a2e6231d783b62e4
   :target: https://app.codacy.com/gh/tZ3ma/cassy/dashboard
   :alt: Codacy Code Quality Status

.. |Codeclimate| image:: https://api.codeclimate.com/v1/badges/ff119252f0bb7f40aecb/maintainability
   :target: https://codeclimate.com/github/tZ3ma/cassy/maintainability
   :alt: Maintainability

.. |Scrutinizer| image:: https://scrutinizer-ci.com/g/tZ3ma/cassy/badges/quality-score.png?b=main
   :target: https://scrutinizer-ci.com/g/tZ3ma/cassy/
   :alt: Scrutinizer Code Quality

.. |pre-commit| image:: https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit&logoColor=white
   :target: https://github.com/pre-commit/pre-commit
   :alt: pre-commit

.. |Black| image:: https://img.shields.io/badge/code%20style-black-000000.svg
   :target: https://github.com/psf/black
   :alt: Black

.. |Pylint| image:: https://img.shields.io/badge/linting-pylint-yellowgreen
   :target: https://github.com/PyCQA/pylint
   :alt: Package uses pylint

.. |Flake8| image:: https://img.shields.io/badge/linting-flake8-yellogreen
   :target: https://github.com/pycqa/flake8
   :alt: Package uses flake8


Manage a **FO**\ rest **G**\ arden cassandra **D**\ ata\ **B**\ ase.

Installation
------------

Please see the `Installation Guide`_ (`Github Repo Link`_) for details.


Usage
-----

Please see the `Worklow Reference <Workflow-Guide_>`_ (`Github Repo Link`_) for details.


Contributing
------------

Contributions are very welcome.
To learn more, see the `Contributor Guide`_ (`Github Repo Link`_).


License
-------

Distributed under the terms of the `MIT license`_ (`Github Repo Link`_),
*cassy* is free and open source software.


Issues
------

If you encounter any problems,
please `file an issue`_ along with a detailed description.

Credits
-------

This project was created using the `Mathias Ammon <tZ3ma>`_ tweaked version of the
Hypermodern-Python_ project foundation proposed by `Claudio Jolowicz <cj>`_.

.. _Hypermodern-Python: https://cjolowicz.github.io/posts/hypermodern-python-01-setup/
.. _Hypermodern Python Cookiecutter: https://github.com/cjolowicz/cookiecutter-hypermodern-python
.. _cj: https://github.com/cjolowicz

.. _MIT license: https://opensource.org/licenses/MIT
.. _PyPI: https://pypi.org/

.. _file an issue: https://github.com/tZ3ma/cassy/issues
.. _pip: https://pip.pypa.io/

.. _tZ3ma: https://github.com/tZ3ma
.. working on github-only
.. _Contributor Guide: CONTRIBUTING.rst
.. _Installation Guide: docs/source/getting_started/installation.rst
.. _Workflow-Guide: docs/source/developer_guide/workflows.rst

.. _Github Repo Link: https://github.com/tZ3ma/cassy
